# Generated by Django 4.1.5 on 2023-09-27 22:25

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.OAUTH2_PROVIDER_ID_TOKEN_MODEL),
        ("tests", "0004_basetestapplication_hash_client_secret_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="basetestapplication",
            name="allowed_origins",
            field=models.TextField(blank=True, help_text="Allowed origins list to enable CORS, space separated"),
        ),
        migrations.AddField(
            model_name="sampleapplication",
            name="allowed_origins",
            field=models.TextField(blank=True, help_text="Allowed origins list to enable CORS, space separated"),
        ),
    ]
