from .settings import *  # noqa


OAUTH2_PROVIDER_ACCESS_TOKEN_MODEL = "tests.SampleAccessToken"
OAUTH2_PROVIDER_APPLICATION_MODEL = "tests.SampleApplication"
OAUTH2_PROVIDER_REFRESH_TOKEN_MODEL = "tests.SampleRefreshToken"
