# Generated by Django 4.2.5 on 2023-09-07 19:28

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.OAUTH2_PROVIDER_ID_TOKEN_MODEL),
        ('tests', '0003_basetestapplication_post_logout_redirect_uris_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='basetestapplication',
            name='hash_client_secret',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='sampleapplication',
            name='hash_client_secret',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='sampleaccesstoken',
            name='id_token',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='s_access_token', to=settings.OAUTH2_PROVIDER_ID_TOKEN_MODEL),
        ),
    ]
